#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypton-x509-validation
version:              1.6.14
visibility:           public
id:                   crypton-x509-validation-1.6.14-5prxGYvnhwJB6fFaiRMUaB
key:                  crypton-x509-validation-1.6.14-5prxGYvnhwJB6fFaiRMUaB
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/kazu-yamamoto/crypton-certificate
synopsis:             X.509 Certificate and CRL validation
description:          X.509 Certificate and CRL validation. please see README
category:             Data
abi:                  cd53acf654787d495ac1f089e7dd6622
exposed:              True
exposed-modules:      Data.X509.Validation
hidden-modules:
    Data.X509.Validation.Signature Data.X509.Validation.Fingerprint
    Data.X509.Validation.Cache Data.X509.Validation.Types

import-dirs:
    /usr/lib/ghc-9.6.6/site-local/crypton-x509-validation-1.6.14

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/crypton-x509-validation-1.6.14

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/crypton-x509-validation-1.6.14

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-x509-validation
hs-libraries:         HScrypton-x509-validation-1.6.14-5prxGYvnhwJB6fFaiRMUaB
depends:
    asn1-encoding-0.9.6-FV31MpHd7Rp4w1LZnO3MI3
    asn1-types-0.3.4-COOqHElL7pK7ALNF378c2H base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7
    crypton-1.0.4-BMCJ5g7BmWBFw24KZjiuHQ
    crypton-x509-1.7.7-7RW3QjjFJAu71jiS3xmeW2
    crypton-x509-store-1.6.12-61gNwGpyYSb6XxOWvZFIqe
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
    hourglass-0.2.12-BoSZTGBQ5wA13E3fJB5emQ
    iproute-1.7.15-840Tt03kEDkHPRMe40WH2F
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5 mtl-2.3.1
    pem-0.2.4-K6BTxAiXLzRDZt9PLVMICt

haddock-interfaces:
    /usr/share/doc/haskell-crypton-x509-validation/html/crypton-x509-validation.haddock

haddock-html:         /usr/share/doc/haskell-crypton-x509-validation/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

